@@ -20,15 +20,17 @@ def get_prediction(ells, chi_i, chi_f, alpha, beta, gamma,
 
 @pytest.fixture(scope='module')
 def set_up():
+    ccl.physical_constants.T_CMB = 2.7
+    ccl.gsl_params.INTEGRATION_LIMBER_EPSREL = 1E-4
+    ccl.gsl_params.INTEGRATION_EPSREL = 1E-4
     cosmo = ccl.Cosmology(Omega_c=0.30, Omega_b=0.00, Omega_g=0, Omega_k=0,
                           h=0.7, sigma8=0.8, n_s=0.96, Neff=0, m_nu=0.0,
                           w0=-1, wa=0, transfer_function='bbks',
                           mass_function='tinker',
                           matter_power_spectrum='linear')
-    cosmo.cosmo.params.T_CMB = 2.7
-    cosmo.cosmo.gsl_params.INTEGRATION_LIMBER_EPSREL = 1E-4
-    cosmo.cosmo.gsl_params.INTEGRATION_EPSREL = 1E-4
 
+    ccl.physical_constants.reload()
+    ccl.gsl_params.reload()
     return cosmo
 
 
