@@ -3,6 +3,7 @@ from ..core import check
 from ..background import omega_x
 from .massdef import MassDef, MassDef200m
 import numpy as np
+import functools
 
 
 class HaloBias(object):
@@ -156,6 +157,23 @@ class HaloBias(object):
         raise NotImplementedError("Use one of the non-default "
                                   "HaloBias classes")
 
+    @classmethod
+    def from_name(cls, name):
+        """Returns halo bias subclass from name string
+
+        Args:
+            name (string): a halo bias name
+
+        Returns:
+            HaloBias subclass corresponding to the input name.
+        """
+        bias_functions = {c.name: c for c in HaloBias.__subclasses__()}
+        if name in bias_functions:
+            return bias_functions[name]
+        else:
+            raise ValueError(
+                f"Halo bias parametrization {name} not implemented")
+
 
 class HaloBiasSheth99(HaloBias):
     """ Implements halo bias described in 1999MNRAS.308..119S
@@ -349,17 +367,6 @@ class HaloBiasTinker10(HaloBias):
             self.B * nu**self.b + C * nu**self.c
 
 
+@functools.wraps(HaloBias.from_name)
 def halo_bias_from_name(name):
-    """ Returns halo bias subclass from name string
-
-    Args:
-        name (string): a halo bias name
-
-    Returns:
-        HaloBias subclass corresponding to the input name.
-    """
-    bias_functions = {c.name: c for c in HaloBias.__subclasses__()}
-    if name in bias_functions:
-        return bias_functions[name]
-    else:
-        raise ValueError("Halo bias parametrization %s not implemented")
+    return HaloBias.from_name(name)
