@@ -1,8 +1,10 @@
 from .. import ccllib as lib
 from ..core import check
 from ..background import omega_x
+from ..parameters import physical_constants
 from .massdef import MassDef, MassDef200m
 import numpy as np
+import functools
 
 
 class MassFunc(object):
@@ -148,7 +150,7 @@ class MassFunc(object):
                                                    len(logM), status)
         check(status, cosmo=cosmo)
 
-        rho = (lib.cvar.constants.RHO_CRITICAL *
+        rho = (physical_constants.RHO_CRITICAL *
                cosmo['Omega_m'] * cosmo['h']**2)
         f = self._get_fsigma(cosmo, sigM, a, 2.302585092994046 * logM)
         mf = f * rho * dlns_dlogM / M_use
@@ -177,6 +179,22 @@ class MassFunc(object):
         raise NotImplementedError("Use one of the non-default "
                                   "MassFunction classes")
 
+    @classmethod
+    def from_name(cls, name):
+        """ Returns mass function subclass from name string
+
+        Args:
+            name (string): a mass function name
+
+        Returns:
+            MassFunc subclass corresponding to the input name.
+        """
+        mass_functions = {c.name: c for c in cls.__subclasses__()}
+        if name in mass_functions:
+            return mass_functions[name]
+        else:
+            raise ValueError(f"Mass function {name} not implemented.")
+
 
 class MassFuncPress74(MassFunc):
     """ Implements mass function described in 1974ApJ...187..425P.
@@ -749,17 +767,6 @@ class MassFuncAngulo12(MassFunc):
             np.exp(-self.c / sigM**2)
 
 
+@functools.wraps(MassFunc.from_name)
 def mass_function_from_name(name):
-    """ Returns mass function subclass from name string
-
-    Args:
-        name (string): a mass function name
-
-    Returns:
-        MassFunc subclass corresponding to the input name.
-    """
-    mass_functions = {c.name: c for c in MassFunc.__subclasses__()}
-    if name in mass_functions:
-        return mass_functions[name]
-    else:
-        raise ValueError("Mass function %s not implemented")
+    return MassFunc.from_name(name)
