@@ -130,7 +130,10 @@ class Tk3D(object):
                                                         int(extrap_order_lok),
                                                         int(is_logt), status)
         check(status)
-        self.has_tsp = True
+
+    @property
+    def has_tsp(self):
+        return 'tsp' in vars(self)
 
     def eval(self, k, a):
         """Evaluate trispectrum. If `k` is a 1D array with size `nk`, the
@@ -163,11 +166,20 @@ class Tk3D(object):
         check(status)
         return f
 
+    def __call__(self, k, a):
+        """Callable vectorized instance."""
+        out = np.array([self.eval(k, aa)
+                        for aa in np.atleast_1d(a).astype(float)])
+        return out.squeeze()[()]
+
     def __del__(self):
         if hasattr(self, 'has_tsp'):
             if self.has_tsp and hasattr(self, 'tsp'):
                 lib.f3d_t_free(self.tsp)
 
+    def __bool__(self):
+        return self.has_tsp
+
     def get_spline_arrays(self):
         """Get the spline data arrays.
 
